Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2213)

Unified Diff: content/public/browser/content_browser_client.h

Issue 18667002: Pass BrowserContext to drive::MountPointProviderDelegate. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/storage_partition_impl.cc ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/content_browser_client.h
diff --git a/content/public/browser/content_browser_client.h b/content/public/browser/content_browser_client.h
index f7a4d20e42889f57faa2e5d2b419b3fdded4476b..9cf7aafc6d5a6286c2d63dbcd35896cb5b94e537 100644
--- a/content/public/browser/content_browser_client.h
+++ b/content/public/browser/content_browser_client.h
@@ -71,10 +71,6 @@ class ExternalMountPoints;
class FileSystemBackend;
}
-namespace quota {
-class SpecialStoragePolicy;
-}
-
namespace content {
class AccessTokenStore;
@@ -562,14 +558,12 @@ class CONTENT_EXPORT ContentBrowserClient {
std::vector<std::string>* additional_schemes) {}
// Returns additional file system backends for FileSystem API.
// |special_storage_policy| and |external_mount_points| are needed in the
// additional FileSystemBackends. |special_storage_policy| is used to grant
// permissions. |external_mount_points| has mount points to create objects
// returned by additional FileSystemBackends.
virtual void GetAdditionalFileSystemBackends(
+ BrowserContext* browser_context,
const base::FilePath& storage_partition_path,
- quota::SpecialStoragePolicy* special_storage_policy,
- fileapi::ExternalMountPoints* external_mount_points,
ScopedVector<fileapi::FileSystemBackend>* additional_backends) {}
// Allows an embedder to return its own LocationProvider implementation.
« no previous file with comments | « content/browser/storage_partition_impl.cc ('k') | no next file » | no next file with comments »
@@ -562,14 +558,12 @@ class CONTENT_EXPORT ContentBrowserClient {
std::vector<std::string>* additional_schemes) {}
// Returns additional file system backends for FileSystem API.
- // |special_storage_policy| and |external_mount_points| are needed in the
- // additional FileSystemBackends. |special_storage_policy| is used to grant
- // permissions. |external_mount_points| has mount points to create objects
- // returned by additional FileSystemBackends.
+ // |browser_context| is needed in the additional FileSystemBackends.
+ // It has mount points to create objects returned by additional
+ // FileSystemBackends, and SpecialStoragePolicy for permission granting.
virtual void GetAdditionalFileSystemBackends(

Powered by Google App Engine
This is Rietveld 408576698